==> dropwizard-revolver-resilience4j-1.0-15-8-20200109.052016-1-sources.jar: io/dropwizard/revolver/core/resilience/ResilienceHttpContext.java <==
package io.dropwizard.revolver.core.resilience;

import com.codahale.metrics.MetricRegistry;
import io.dropwizard.revolver.core.config.resilience.ResilienceConfig;
import io.dropwizard.revolver.core.config.resilience.ThreadPoolConfig;
import io.dropwizard.revolver.http.RevolverHttpContext;
import io.github.resilience4j.bulkhead.Bulkhead;
import io.github.resilience4j.circuitbreaker.CircuitBreaker;
import java.util.Map;
import java.util.concurrent.ArrayBlockingQueue;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/***
 Created by nitish.goyal on 23/11/19
 ***/
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class ResilienceHttpContext extends RevolverHttpContext {

    private CircuitBreaker defaultCircuitBreaker;

    private Map<String, CircuitBreaker> apiVsCircuitBreaker;

    private Map<String, Bulkhead> poolVsBulkHeadMap;

    private Map<String, Integer> apiVsTimeout;

    private ExecutorService executor;

    private MetricRegistry metrics;

    private ResilienceConfig resilienceConfig;

    @Builder
    public ResilienceHttpContext(CircuitBreaker defaultCircuitBreaker,
            Map<String, CircuitBreaker> apiVsCircuitBreaker,
            Map<String, Bulkhead> poolVsBulkHeadMap, Map<String, Integer> apiVsTimeout,
            MetricRegistry metrics, ResilienceConfig resilienceConfig) {
        this.defaultCircuitBreaker = defaultCircuitBreaker;
        this.apiVsCircuitBreaker = apiVsCircuitBreaker;
        this.poolVsBulkHeadMap = poolVsBulkHeadMap;
        this.apiVsTimeout = apiVsTimeout;
        this.metrics = metrics;
        this.resilienceConfig = resilienceConfig;

        ThreadPoolConfig threadPoolConfig = resilienceConfig.getThreadPoolConfig();
        this.executor = new ThreadPoolExecutor(threadPoolConfig.getCorePoolSize(), threadPoolConfig.getMaxPoolSize(),
                threadPoolConfig.getKeepAliveTimeInSeconds(), TimeUnit.SECONDS,
                new ArrayBlockingQueue<>(threadPoolConfig.getQueueSize()));
    }
}

==> dropwizard-revolver-resilience4j-1.0-15-9-20200109.054328-1-sources.jar: io/dropwizard/revolver/core/resilience/ResilienceHttpContext.java <==
package io.dropwizard.revolver.core.resilience;

import com.codahale.metrics.MetricRegistry;
import io.dropwizard.revolver.core.config.resilience.ResilienceConfig;
import io.dropwizard.revolver.core.config.resilience.ThreadPoolConfig;
import io.dropwizard.revolver.http.RevolverHttpContext;
import io.github.resilience4j.bulkhead.Bulkhead;
import io.github.resilience4j.circuitbreaker.CircuitBreaker;
import java.util.Map;
import java.util.concurrent.ArrayBlockingQueue;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;

/***
 Created by nitish.goyal on 23/11/19
 ***/
@Data
@Builder
@AllArgsConstructor
public class ResilienceHttpContext extends RevolverHttpContext {

    private CircuitBreaker defaultCircuitBreaker;

    private Map<String, CircuitBreaker> apiVsCircuitBreaker;

    private Map<String, Bulkhead> poolVsBulkHeadMap;

    private Map<String, Integer> apiVsTimeout;

    private ExecutorService executor;

    private MetricRegistry metrics;

    private ResilienceConfig resilienceConfig;

    public ResilienceHttpContext() {
        if (resilienceConfig == null) {
            resilienceConfig = new ResilienceConfig();
        }
        ThreadPoolConfig threadPoolConfig = resilienceConfig.getThreadPoolConfig();
        this.executor = new ThreadPoolExecutor(threadPoolConfig.getCorePoolSize(), threadPoolConfig.getMaxPoolSize(),
                threadPoolConfig.getKeepAliveTimeInSeconds(), TimeUnit.SECONDS,
                new ArrayBlockingQueue<>(threadPoolConfig.getQueueSize()));

    }

    @Builder
    public ResilienceHttpContext(CircuitBreaker defaultCircuitBreaker,
            Map<String, CircuitBreaker> apiVsCircuitBreaker,
            Map<String, Bulkhead> poolVsBulkHeadMap, Map<String, Integer> apiVsTimeout,
            MetricRegistry metrics, ResilienceConfig resilienceConfig) {
        this.defaultCircuitBreaker = defaultCircuitBreaker;
        this.apiVsCircuitBreaker = apiVsCircuitBreaker;
        this.poolVsBulkHeadMap = poolVsBulkHeadMap;
        this.apiVsTimeout = apiVsTimeout;
        this.metrics = metrics;
        this.resilienceConfig = resilienceConfig;

        ThreadPoolConfig threadPoolConfig = resilienceConfig.getThreadPoolConfig();
        this.executor = new ThreadPoolExecutor(threadPoolConfig.getCorePoolSize(), threadPoolConfig.getMaxPoolSize(),
                threadPoolConfig.getKeepAliveTimeInSeconds(), TimeUnit.SECONDS,
                new ArrayBlockingQueue<>(threadPoolConfig.getQueueSize()));
    }
}
